@@ -105,7 +105,7 @@
 #line 1 "i386_parse.y"
 
 /* Parser for i386 CPU description.
-   Copyright (C) 2004, 2005, 2007, 2008 Red Hat, Inc.
+   Copyright (C) 2004, 2005, 2007, 2008, 2009 Red Hat, Inc.
    Written by Ulrich Drepper <drepper@redhat.com>, 2004.
 
    Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -142,6 +142,7 @@
 #include <math.h>
 #include <obstack.h>
 #include <search.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -335,7 +336,7 @@ static size_t best_mnemonic_bits;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 213 "i386_parse.y"
+#line 214 "i386_parse.y"
 {
   unsigned long int num;
   char *str;
@@ -346,7 +347,7 @@ typedef union YYSTYPE
   struct argument *arg;
 }
 /* Line 187 of yacc.c.  */
-#line 350 "i386_parse.c"
+#line 351 "i386_parse.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -359,7 +360,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 363 "i386_parse.c"
+#line 364 "i386_parse.c"
 
 #ifdef short
 # undef short
@@ -652,10 +653,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   243,   243,   253,   254,   257,   259,   261,   263,   275,
-     278,   279,   282,   365,   368,   384,   387,   397,   404,   412,
-     416,   423,   430,   452,   455,   458,   468,   476,   484,   487,
-     519,   528,   535
+       0,   244,   244,   254,   255,   258,   260,   262,   264,   276,
+     279,   280,   283,   366,   369,   385,   388,   398,   405,   413,
+     417,   424,   431,   453,   456,   459,   469,   477,   485,   488,
+     520,   529,   536
 };
 #endif
 
@@ -1582,7 +1583,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 244 "i386_parse.y"
+#line 245 "i386_parse.y"
     {
 		      if (error_message_count != 0)
 			error (EXIT_FAILURE, 0,
@@ -1593,22 +1594,22 @@ yyreduce:
     break;
 
   case 5:
-#line 258 "i386_parse.y"
+#line 259 "i386_parse.y"
     { new_bitfield ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].num)); }
     break;
 
   case 6:
-#line 260 "i386_parse.y"
+#line 261 "i386_parse.y"
     { new_bitfield ((yyvsp[(2) - (2)].str), -1); }
     break;
 
   case 7:
-#line 262 "i386_parse.y"
+#line 263 "i386_parse.y"
     { new_bitfield ((yyvsp[(2) - (2)].str), -2); }
     break;
 
   case 8:
-#line 264 "i386_parse.y"
+#line 265 "i386_parse.y"
     {
 		      struct synonym *newp = xmalloc (sizeof (*newp));
 		      newp->from = (yyvsp[(2) - (3)].str);
@@ -1623,7 +1624,7 @@ yyreduce:
     break;
 
   case 12:
-#line 283 "i386_parse.y"
+#line 284 "i386_parse.y"
     {
 		      if ((yyvsp[(3) - (6)].field) != NULL && strcmp ((yyvsp[(3) - (6)].field)->name, "RE") != 0
 			  && strcmp ((yyvsp[(3) - (6)].field)->name, "R") != 0)
@@ -1709,7 +1710,7 @@ yyreduce:
     break;
 
   case 14:
-#line 369 "i386_parse.y"
+#line 370 "i386_parse.y"
     {
 		      struct known_bitfield search;
 		      search.name = (yyvsp[(1) - (1)].str);
@@ -1727,12 +1728,12 @@ yyreduce:
     break;
 
   case 15:
-#line 384 "i386_parse.y"
+#line 385 "i386_parse.y"
     { (yyval.field) = NULL; }
     break;
 
   case 16:
-#line 388 "i386_parse.y"
+#line 389 "i386_parse.y"
     {
 		      check_bits ((yyvsp[(3) - (3)].bit));
 
@@ -1745,7 +1746,7 @@ yyreduce:
     break;
 
   case 17:
-#line 398 "i386_parse.y"
+#line 399 "i386_parse.y"
     {
 		      check_bits ((yyvsp[(1) - (1)].bit));
 		      (yyval.bit) = (yyvsp[(1) - (1)].bit);
@@ -1753,7 +1754,7 @@ yyreduce:
     break;
 
   case 18:
-#line 405 "i386_parse.y"
+#line 406 "i386_parse.y"
     {
 		      struct bitvalue *runp = (yyvsp[(1) - (2)].bit);
 		      while (runp->next != NULL)
@@ -1764,12 +1765,12 @@ yyreduce:
     break;
 
   case 19:
-#line 413 "i386_parse.y"
+#line 414 "i386_parse.y"
     { (yyval.bit) = (yyvsp[(1) - (1)].bit); }
     break;
 
   case 20:
-#line 417 "i386_parse.y"
+#line 418 "i386_parse.y"
     {
 		      (yyval.bit) = xmalloc (sizeof (struct bitvalue));
 		      (yyval.bit)->type = zeroone;
@@ -1779,7 +1780,7 @@ yyreduce:
     break;
 
   case 21:
-#line 424 "i386_parse.y"
+#line 425 "i386_parse.y"
     {
 		      (yyval.bit) = xmalloc (sizeof (struct bitvalue));
 		      (yyval.bit)->type = zeroone;
@@ -1789,7 +1790,7 @@ yyreduce:
     break;
 
   case 22:
-#line 431 "i386_parse.y"
+#line 432 "i386_parse.y"
     {
 		      (yyval.bit) = xmalloc (sizeof (struct bitvalue));
 		      struct known_bitfield search;
@@ -1812,17 +1813,17 @@ yyreduce:
     break;
 
   case 23:
-#line 453 "i386_parse.y"
+#line 454 "i386_parse.y"
     { (yyval.arg) = (yyvsp[(2) - (2)].arg); }
     break;
 
   case 24:
-#line 455 "i386_parse.y"
+#line 456 "i386_parse.y"
     { (yyval.arg) = NULL; }
     break;
 
   case 25:
-#line 459 "i386_parse.y"
+#line 460 "i386_parse.y"
     {
 		      struct argument *runp = (yyvsp[(1) - (3)].arg);
 		      while (runp->next != NULL)
@@ -1835,7 +1836,7 @@ yyreduce:
     break;
 
   case 26:
-#line 469 "i386_parse.y"
+#line 470 "i386_parse.y"
     {
 		      (yyval.arg) = xmalloc (sizeof (struct argument));
 		      (yyval.arg)->name = combine ((yyvsp[(1) - (1)].name));
@@ -1844,7 +1845,7 @@ yyreduce:
     break;
 
   case 27:
-#line 477 "i386_parse.y"
+#line 478 "i386_parse.y"
     {
 		      struct argname *runp = (yyvsp[(1) - (2)].name);
 		      while (runp->next != NULL)
@@ -1855,12 +1856,12 @@ yyreduce:
     break;
 
   case 28:
-#line 485 "i386_parse.y"
+#line 486 "i386_parse.y"
     { (yyval.name) = (yyvsp[(1) - (1)].name); }
     break;
 
   case 29:
-#line 488 "i386_parse.y"
+#line 489 "i386_parse.y"
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = nfield;
@@ -1895,7 +1896,7 @@ yyreduce:
     break;
 
   case 30:
-#line 520 "i386_parse.y"
+#line 521 "i386_parse.y"
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = string;
@@ -1907,7 +1908,7 @@ yyreduce:
     break;
 
   case 31:
-#line 529 "i386_parse.y"
+#line 530 "i386_parse.y"
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = string;
@@ -1917,7 +1918,7 @@ yyreduce:
     break;
 
   case 32:
-#line 536 "i386_parse.y"
+#line 537 "i386_parse.y"
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = string;
@@ -1930,7 +1931,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1934 "i386_parse.c"
+#line 1935 "i386_parse.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2144,7 +2145,7 @@ yyreturn:
 }
 
 
-#line 546 "i386_parse.y"
+#line 547 "i386_parse.y"
 
 
 static void
@@ -2850,6 +2851,8 @@ instrtable_out (void)
       /* First count the number of bytes.  */
       size_t totalbits = 0;
       size_t zerobits = 0;
+      bool leading_p = true;
+      size_t leadingbits = 0;
       struct bitvalue *b = instr->bytes;
       while (b != NULL)
 	{
@@ -2857,6 +2860,8 @@ instrtable_out (void)
 	    {
 	      ++totalbits;
 	      zerobits = 0;
+	      if (leading_p)
+		++leadingbits;
 	    }
 	  else
 	    {
@@ -2866,13 +2871,15 @@ instrtable_out (void)
 		zerobits = 0;
 	      else
 		zerobits += b->field->bits;
+	      leading_p = false;
 	    }
 	  b = b->next;
 	}
       size_t nbytes = (totalbits - zerobits + 7) / 8;
       assert (nbytes > 0);
+      size_t leadingbytes = leadingbits / 8;
 
-      fprintf (outfile, "  %#zx,", nbytes);
+      fprintf (outfile, "  %#zx,", nbytes | (leadingbytes << 4));
 
       /* Now create the mask and byte values.  */
       uint8_t byte = 0;
@@ -2887,7 +2894,15 @@ instrtable_out (void)
 	      mask = (mask << 1) | 1;
 	      if (++nbits == 8)
 		{
-		  fprintf (outfile, " %#" PRIx8 ", %#" PRIx8 ",", mask, byte);
+		  if (leadingbytes > 0)
+		    {
+		      assert (mask == 0xff);
+		      fprintf (outfile, " %#" PRIx8 ",", byte);
+		      --leadingbytes;
+		    }
+		  else
+		    fprintf (outfile, " %#" PRIx8 ", %#" PRIx8 ",",
+			     mask, byte);
 		  byte = mask = nbits = 0;
 		  if (--nbytes == 0)
 		    break;
@@ -2895,6 +2910,8 @@ instrtable_out (void)
 	    }
 	  else
 	    {
+	      assert (leadingbytes == 0);
+
 	      unsigned long int remaining = b->field->bits;
 	      while (nbits + remaining > 8)
 		{
